/**********************************************************************************************
    Copyright (C) 2020 Oliver Eichler <oliver.eichler@gmx.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#ifndef IPOIPROP_H
#define IPOIPROP_H

#include <QWidget>

class CPoiDraw;
class IPoiFile;

class IPoiProp : public QWidget {
  Q_OBJECT
 public:
  IPoiProp(IPoiFile* poifile, CPoiDraw* poi);
  virtual ~IPoiProp() = default;

 protected slots:
  virtual void slotPropertiesChanged() = 0;

 protected:
  IPoiFile* poifile;
  CPoiDraw* poi;
};

#endif  // IPOIPROP_H
